@@ -1,5 +1,6 @@
+from typing import Optional
 from pydom.types.html.html_element_props import HTMLElementProps
 
 
 class HTMLListItemElement(HTMLElementProps, total=False):
-    value: str
+    value: Optional[str]
